==> deltatwin_cli-1.3.1.tar.gz: deltatwin_cli-1.3.1/tests/artifact/test_artifact.py <==
import json
import os
import unittest
from unittest.mock import patch

from click.testing import CliRunner

from delta.cli import delta_cli
from delta.cli.utils import API
from tests.utils import remove_conf


class TestDeltaArtifact(unittest.TestCase):
    service_url = 'https://delta_api'
    resource_dir = os.path.join(os.path.dirname(__file__),
                                '..', 'resources', 'artifact')
    runner = None

    @classmethod
    def setUpClass(cls) -> None:
        cls.runner = CliRunner()
        remove_conf()

    @classmethod
    def tearDownClass(cls) -> None:
        remove_conf()

    def test_artifact_list_without_conf(self):
        result = self.runner.invoke(
            delta_cli,
            ["drive", "artifact", "list", "-c", "conf.ini"],
            catch_exceptions=False
        )
        self.assertEqual(result.exit_code, 6)
        self.assertIn(
            "No token find please use deltatwin login"
            " before using this command",
            result.output)

    def test_artifact_list(self):
        with open(os.path.join(self.resource_dir, 'artifacts.json')) as f:
            data = json.load(f)

        with patch.object(API, 'list_artifact',
                          return_value=data
                          ):
            result = self.runner.invoke(
                delta_cli,
                ["drive", "artifact", "list", "-c", "conf.ini"],
                catch_exceptions=False
            )
        self.assertEqual(result.exit_code, 0)

    def test_artifact_list_json(self):
        with open(os.path.join(self.resource_dir, 'artifacts.json')) as f:
            data = json.load(f)

        with patch.object(API, 'list_artifact',
                          return_value=data
                          ):
            result = self.runner.invoke(
                delta_cli,
                ["drive", "artifact", "list", "-f", "json", "-c", "conf.ini"],
                catch_exceptions=False
            )
        with open(os.path.join(self.resource_dir,
                               'artifacts.json')) as f:
            data = json.loads(f.read())

        self.assertEqual(result.exit_code, 0)
        self.assertEqual(data, json.loads(result.output))

==> deltatwin_cli-1.4.0.tar.gz: deltatwin_cli-1.4.0/tests/artifact/test_artifact.py <==
import json
import os
import unittest
from unittest.mock import patch

from click.testing import CliRunner

from delta.cli import delta_cli
from delta.cli.utils import API
from tests.utils import remove_conf


class TestDeltaArtifact(unittest.TestCase):
    service_url = 'https://delta_api'
    resource_dir = os.path.join(os.path.dirname(__file__),
                                '..', 'resources', 'artifact')
    runner = None

    @classmethod
    def setUpClass(cls) -> None:
        cls.runner = CliRunner()
        remove_conf()

    @classmethod
    def tearDownClass(cls) -> None:
        remove_conf()

    def test_artifact_list_without_conf(self):
        result = self.runner.invoke(
            delta_cli,
            ["drive", "artifact", "list", "-c", "conf.ini"],
            catch_exceptions=False
        )
        self.assertEqual(result.exit_code, 6)
        self.assertIn(
            "No config find please use deltatwin login"
            " before using this command",
            result.output)

    def test_artifact_list(self):
        with open(os.path.join(self.resource_dir, 'artifacts.json')) as f:
            data = json.load(f)

        with patch.object(API, 'list_artifact',
                          return_value=data
                          ):
            result = self.runner.invoke(
                delta_cli,
                ["drive", "artifact", "list", "-c", "conf.ini"],
                catch_exceptions=False
            )
        self.assertEqual(result.exit_code, 0)

    def test_artifact_list_json(self):
        with open(os.path.join(self.resource_dir, 'artifacts.json')) as f:
            data = json.load(f)

        with patch.object(API, 'list_artifact',
                          return_value=data
                          ):
            result = self.runner.invoke(
                delta_cli,
                ["drive", "artifact", "list", "-f", "json", "-c", "conf.ini"],
                catch_exceptions=False
            )
        with open(os.path.join(self.resource_dir,
                               'artifacts.json')) as f:
            data = json.loads(f.read())

        self.assertEqual(result.exit_code, 0)
        self.assertEqual(data, json.loads(result.output))
